@@ -33,19 +33,19 @@ class SmallIntArray(object):
 
 if __name__ == '__main__':
     from random import randint
-    
+
     # define array with 1000 integers, each represented by 5 bits
     a = SmallIntArray(1000, 5)
 
-    b = [] # store values, for assertion below 
-    for i in xrange(1000):
+    b = [] # store values, for assertion below
+    for i in range(1000):
         v = randint(0, 31)
         b.append(v)
         a[i] = v
 
-    print b[:5]
-    print a.data.buffer_info()
-    print a.data[:25]
+    print(b[:5])
+    print(a.data.buffer_info())
+    print(a.data[:25])
 
-    for i in xrange(1000):
+    for i in range(1000):
         assert a[i] == b[i]
